@@ -24,7 +24,22 @@ def do_benchmark():
     config = hazelcast.ClientConfig()
     config.group_config.name = "dev"
     config.group_config.password = "dev-pass"
-    config.network_config.addresses.append("127.0.0.1:5701")
+
+    try:
+        from hzrc.client import HzRemoteController
+
+        rc = HzRemoteController('127.0.0.1', '9701')
+
+        if not rc.ping():
+            logger.info("Remote Controller Server not running... exiting.")
+            exit()
+        logger.info("Remote Controller Server OK...")
+        rc_cluster = rc.createCluster(None, None)
+        rc_member = rc.startMember(rc_cluster.id)
+        config.network_config.addresses.append('{}:{}'.format(rc_member.host, rc_member.port))
+    except (ImportError, NameError):
+        config.network_config.addresses.append('127.0.0.1')
+
     client = hazelcast.HazelcastClient(config)
     my_map = client.get_map("default")
     for i in xrange(0, 1000):
